@@ -383,14 +383,16 @@ ews_oab_read_upto (GInputStream *is,
 	GString *str;
 
 	str = g_string_sized_new (size);
-	do {
+	while (1) {
 		gsize len;
 		gsize bytes_read;
 		gchar *c = g_malloc0 (size);
 
-		g_input_stream_read_all (is, c, size, &bytes_read, cancellable, error);
-		if (*error)
+		if (!g_input_stream_read_all (is, c, size, &bytes_read,
+					      cancellable, error)) {
+			g_free (c);
 			break;
+		}
 
 		if (bytes_read != size)
 			size = bytes_read;
@@ -399,6 +401,8 @@ ews_oab_read_upto (GInputStream *is,
 		if (len)
 			str = g_string_append_len (str, c, len);
 
+		g_free (c);
+
 		if (len == 0 || len < size) {
 			goffset seek = (goffset) len + 1 - (goffset) size;
 
@@ -408,8 +412,7 @@ ews_oab_read_upto (GInputStream *is,
 		}
 
 		size *= 2;
-		g_free (c);
-	} while (!*error);
+	}
 
 	return g_string_free (str, FALSE);
 }
@@ -712,14 +715,17 @@ ews_decode_oab_prop (EwsOabDecoder *eod,
 						val = ews_oab_read_upto (G_INPUT_STREAM (priv->fis), '\0', cancellable, error);
 					}
 
-					if (*error) {
+					if (!val) {
 						g_slist_foreach (list, (GFunc) g_free, NULL);
 						g_slist_free (list);
 						return NULL;
 					}
+
+					list = g_slist_prepend (list, val);
 				}
 
 			}
+			ret_val = list;
 
 			break;
 		}
