@@ -87,10 +87,6 @@ camel_ews_utils_build_folder_info (CamelEwsStore *store,
 	return fi;
 }
 
-static void
-add_folder_to_summary (CamelEwsStore *store,
-                       EEwsFolder *folder);
-
 static void
 sync_deleted_folders (CamelEwsStore *store,
                       GSList *deleted_folders)
@@ -175,13 +171,6 @@ sync_updated_folders (CamelEwsStore *store,
 		folder_name = camel_ews_store_summary_get_folder_full_name (
 			ews_summary, fid->id, NULL);
 
-		if (!folder_name) {
-			/* in case the folder is not in the local store summary,
-			   just add it as a new folder */
-			add_folder_to_summary (store, ews_folder);
-			continue;
-		}
-
 		pfid = e_ews_folder_get_parent_id (ews_folder);
 		display_name = g_strdup (e_ews_folder_get_name (ews_folder));
 
