@@ -105,6 +105,8 @@ ews_oof_settings_text_from_html (gchar *html_text)
 	gchar *start, *end;
 	gchar *ii, *jj;
 
+	/* Note, this consumes the input string. */
+
 	g_return_val_if_fail (html_text != NULL, NULL);
 
 	haystack_len = strlen (html_text);
@@ -129,6 +131,8 @@ ews_oof_settings_text_from_html (gchar *html_text)
 	}
 	*jj = '\0';
 
+	g_free (html_text);
+
 	return plain_text;
 }
 
@@ -144,7 +148,6 @@ ews_oof_settings_get_response_cb (ESoapResponse *response,
 	ESoapParameter *subsubparam;
 	GDateTime *date_time;
 	gchar *string;
-	gchar *text;
 	GError *error = NULL;
 
 	param = e_soap_response_get_first_parameter_by_name (
@@ -236,34 +239,24 @@ ews_oof_settings_get_response_cb (ESoapResponse *response,
 	subsubparam = e_soap_parameter_get_first_child_by_name (
 		subparam, "Message");
 	string = e_soap_parameter_get_string_value (subsubparam);
-	if (string == NULL)
-		text = NULL;
-	else if (g_strrstr (string, "</body>") != NULL)
-		text = ews_oof_settings_text_from_html (string);
+	if (g_strrstr (string, "</body>") != NULL)
+		string = ews_oof_settings_text_from_html (string);
 	else if (g_strrstr (string, "BodyFragment") != NULL)
-		text = ews_oof_settings_text_from_html (string);
-	else
-		text = g_strdup (string);
-	e_ews_oof_settings_set_internal_reply (settings, text ? text : "");
+		string = ews_oof_settings_text_from_html (string);
+	e_ews_oof_settings_set_internal_reply (settings, string);
 	g_free (string);
-	g_free (text);
 
 	subparam = e_soap_parameter_get_first_child_by_name (
 		param, "ExternalReply");
 	subsubparam = e_soap_parameter_get_first_child_by_name (
 		subparam, "Message");
 	string = e_soap_parameter_get_string_value (subsubparam);
-	if (string == NULL)
-		text = NULL;
-	else if (g_strrstr (string, "</body>") != NULL)
-		text = ews_oof_settings_text_from_html (string);
+	if (g_strrstr (string, "</body>") != NULL)
+		string = ews_oof_settings_text_from_html (string);
 	else if (g_strrstr (string, "BodyFragment") != NULL)
-		text = ews_oof_settings_text_from_html (string);
-	else
-		text = g_strdup (string);
-	e_ews_oof_settings_set_external_reply (settings, text ? text : "");
+		string = ews_oof_settings_text_from_html (string);
+	e_ews_oof_settings_set_external_reply (settings, string);
 	g_free (string);
-	g_free (text);
 
 	g_object_unref (source_object);
 }
@@ -465,6 +458,7 @@ ews_oof_settings_initable_init_async (GAsyncInitable *initable,
 	ESoapMessage *message;
 	const gchar *uri, *impersonate_user;
 	const gchar *mailbox;
+	EEwsServerVersion version;
 
 	settings = E_EWS_OOF_SETTINGS (initable);
 	connection = e_ews_oof_settings_get_connection (settings);
@@ -472,10 +466,17 @@ ews_oof_settings_initable_init_async (GAsyncInitable *initable,
 	uri = e_ews_connection_get_uri (connection);
 	impersonate_user = e_ews_connection_get_impersonate_user (connection);
 	mailbox = e_ews_connection_get_mailbox (connection);
+	version = e_ews_connection_get_server_version (connection);
 
 	message = e_ews_message_new_with_header (
-		uri, impersonate_user, "GetUserOofSettingsRequest",
-		NULL, NULL, EWS_EXCHANGE_2007_SP1);
+		uri,
+		impersonate_user,
+		"GetUserOofSettingsRequest",
+		NULL,
+		NULL,
+		version,
+		E_EWS_EXCHANGE_2007_SP1,
+		FALSE);
 
 	e_soap_message_start_element (message, "Mailbox", NULL, NULL);
 	e_ews_message_write_string_parameter (
@@ -962,6 +963,7 @@ e_ews_oof_settings_submit (EEwsOofSettings *settings,
 	gchar *external_reply;
 	gchar *start_time;
 	gchar *end_time;
+	EEwsServerVersion version;
 
 	g_return_if_fail (E_IS_EWS_OOF_SETTINGS (settings));
 
@@ -969,6 +971,7 @@ e_ews_oof_settings_submit (EEwsOofSettings *settings,
 	mailbox = e_ews_connection_get_mailbox (connection);
 	uri = e_ews_connection_get_uri (connection);
 	impersonate_user = e_ews_connection_get_impersonate_user (connection);
+	version = e_ews_connection_get_server_version (connection);
 
 	internal_reply = e_ews_oof_settings_dup_internal_reply (settings);
 	external_reply = e_ews_oof_settings_dup_external_reply (settings);
@@ -982,8 +985,14 @@ e_ews_oof_settings_submit (EEwsOofSettings *settings,
 	g_date_time_unref (date_time);
 
 	message = e_ews_message_new_with_header (
-		uri, impersonate_user, "SetUserOofSettingsRequest",
-		NULL, NULL, EWS_EXCHANGE_2007_SP1);
+		uri,
+		impersonate_user,
+		"SetUserOofSettingsRequest",
+		NULL,
+		NULL,
+		version,
+		E_EWS_EXCHANGE_2007_SP1,
+		FALSE);
 
 	/* <Mailbox> */
 
